// src/index.ts
function src_default(options = {}) {
  const { levels, addClass = true } = options;
  return (root) => {
    if (isParent(root)) {
      _sectionize(root.children[0], 0, root);
    }
  };
  function _sectionize(node, index, parent) {
    if (isParent(node)) {
      _sectionize(node.children[0], 0, node);
    }
    const level = node.depth ?? 7;
    if (level < 7 && (!levels || levels.includes(level))) {
      const section = {
        type: "section",
        data: {
          hName: "section",
          hProperties: addClass ? { class: getClass(addClass, level) } : {}
        },
        children: []
      };
      const childCount = countChildren(parent.children, index, level);
      section.children = parent.children.splice(index, childCount, section);
      if (section.children.length > 1) {
        _sectionize(section.children[1], 1, section);
      }
    }
    const next = index + 1;
    if (parent.children.length > next) {
      _sectionize(parent.children[next], next, parent);
    }
  }
}
function isParent(node) {
  return Object.keys(node).includes("children") && Array.isArray(node.children) && node.children.length > 0;
}
function getClass(addClass, level) {
  return typeof addClass === "boolean" ? `h${level}` : `${addClass} ${addClass}--h${level}`;
}
function countChildren(children, start, level) {
  let count = 1;
  for (; start + count < children.length; count++) {
    const child = children[start + count];
    if ((child.depth ?? 7) <= level)
      return count;
  }
  return count;
}
export {
  src_default as default
};
